==> stats_V2.4_2011-11-25_43.tar.gz: stats_V2.4_2011-11-25_43/stats/newuser.php <==
<?
require_once(dirname(__FILE__) . "/lib/defines.php");
/*
echo "<pre>";
var_dump($_REQUEST);
echo "</pre>";
*/

//Only for admin page :
if($_SESSION['admin'] != 1 )
  return;

function extract_var($varname,$value){
  if(!is_array($value)){
    preg_match('/^'.$varname.'_(.*)$/', $value, $matches);
    if(isset($matches[1])){
      return $matches[1];
    }
  }
  return false;
}

function gen_select($array,$name,$selected){
  $select = '<select name="'.$name.'" id="'.$name.'" size="1">'."\n";
  foreach($array as $key => $val){
    $select .= "\t".'<option value="'.$val.'"';
    if( $key == $selected)
      $select .= ' selected ';
    $select .= '>';
    $select .= "$key</option>\n";
  }
  return $select .= '</select>';
}

function usernameexists($username){
  if($username != '' ){
    $db=DbConnect();
    $db -> Halt_On_Error = "no";
    $db->query("SELECT username from ".DB_TABLEUSERS." where username='$username'");
    if($db -> num_rows() !== 0 )
      return true;
  }
  return false;
}



//create USER ?
if($_POST['create_user']){
  if($_POST['username'] === '' )
    $message='<font color="red">Error: Username is empty</font>';
  elseif($_POST["password"] !== $_POST["password2"])
    $message='<font color="red">Error: Passwords given are not identical</font>';
  elseif($_POST["password"] === '')
    $message='<font color="red">Error:Password can\'t be empty</font>';
  elseif(usernameexists($_POST['username']))
    $message='<font color="red">Error : Username allready exists</font>';
  else{
    //Realy create:
    $db=DbConnect();
    $db -> Halt_On_Error = "no";
    $userinfos=serialize(array(
    'search'=>$_POST['search'],
    'discols'=>$_POST['discols'],
    ));
    $query ="INSERT INTO ".DB_TABLEUSERS." SET ";
    $query.=" username='".$_POST['username']."' ,";
    $query.=" password=SHA1('".$_POST["password"]."+".SALT."') ,";
    $query.=" userinfos='$userinfos' ,";
    $query.=" admin='".$_POST['admin']."' ,";
    $query.=" updated=NOW(), created=NOW() ";
    $db -> query($query);
    //echo "AFF: ".$db->affected_rows();
    ?>
    <!-- Report Creation -->
    <center>
    <table width="60%" border="0"><tr>
    <td colspan="2" align="center">
    <h1>User <?=$_POST['username']?> has been created</h1>
    </td></tr>
    <tr>
    <td align="center">
    </td>
    <td align="center">
    <a href="?s=14" title="Back to Users list"><img src="images/back.png" border="0"><br>Continue</a>
    </td>
    </tr></table></center>
    <?return;
  }
}

?>


<center>
<b>Creating a new user</b><br><br>
<FORM METHOD=POST ACTION="?s=<?=$s?>">
<table class="bar-status" width="450" border="0" cellspacing="1" cellpadding="2" align="center">
<tbody>
<?
//Generate array from GLOBALS
$discols_array['default']='';
$search_array['default']='';

foreach($GLOBALS as $key=>$value){
  $res_cols=extract_var('_FG_TABLE_COL',$key);
  $res_search=extract_var('_VCHAR_SEARCH',$key);
  if($res_cols)
    $discols_array[$res_cols]=$res_cols;
  if($res_search)
    $search_array[$res_search]=$res_search;
}


$colors = array ( 1 => array ('555577','cddeff'), 0 => array('000033','acbdee'));
$INPUTS=array(
  "username"  => array('desc'=>"User Name :",'type'=>"input",'size'=>'18','value'=>$_POST['username']),
  "password"  => array('desc'=>"New Password :",'type'=>"password",'size'=>'18','value'=>$_POST['password']),
  "password2" => array('desc'=>"Confirm Password :",'type'=>"password",'size'=>'18','value'=>$_POST['password2']),
  "search"  => array('desc'=>"Search View :",'type'=>"select", 'value'=>$_POST['search'],'values'=>$search_array),
  "discols"  => array('desc'=>"Log View :",'type'=>"select", 'value'=>$_POST['discols'],'values'=>$discols_array),
  "admin" => array('desc'=>"Administrator :",'type'=>"checkbox",'value'=>$_POST['admin']==1?'checked':''),
);
foreach($INPUTS as $varname => $description){
$cpt++;


?>
		<tr>
				<td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][0]?>">			
					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?=$description['desc']?></b></font>
				</td>				
				<td class="bar-search" align="left" bgcolor="#<?=$colors[$cpt%2][1]?>">
				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr>
          <?switch ($description['type']) {
            case "select":?><td>&nbsp;&nbsp;
          <?=gen_select($description['values'],$varname,$description['value']);?></td>
            <?break;
            case "checkbox":?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?=$description['type']?>" NAME="<?=$varname?>" value="1" <?=$description['value']?>"></td>
            <?break;
            default:?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?=$description['type']?>" NAME="<?=$varname?>" value="<?=$description['value']?>" size="<?=$description['size']?>"></td>
            <?break;?>
          <?}?>
  				</tr>
        </table></td>
			</tr>			
	<?
} 
$cpt++;
?>
     <td class="bar-search" align="left" bgcolor="#<?=$colors[$cpt%2][0]?>"> </td>
				<td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][1]?>">
					<input type="submit" align="top" border="0" name="create_user" value="Create New User" />
	  			</td>
    		</tr>
		</tbody></table>
	</FORM>
<br>
<?
if($message)
  echo "$message";
else
  echo "<br>";
?>
</center>

==> stats_V2.7_2014-11-05_52.tar.gz: stats_V2.7_2014-11-05_52/stats/newuser.php <==
<?php
require_once(dirname(__FILE__) . "/lib/defines.php");
/*
echo "<pre>";
var_dump($_REQUEST);
echo "</pre>";
*/

//Only for admin page :
if($_SESSION['admin'] != 1 )
  return;

function extract_var($varname,$value){
  if(!is_array($value)){
    preg_match('/^'.$varname.'_(.*)$/', $value, $matches);
    if(isset($matches[1])){
      return $matches[1];
    }
  }
  return false;
}

function gen_select($array,$name,$selected){
  $select = '<select name="'.$name.'" id="'.$name.'" size="1">'."\n";
  foreach($array as $key => $val){
    $select .= "\t".'<option value="'.$val.'"';
    if( $key == $selected)
      $select .= ' selected ';
    $select .= '>';
    $select .= "$key</option>\n";
  }
  return $select .= '</select>';
}

function usernameexists($username){
  if($username != '' ){
    $db=DbConnect();
    $db -> Halt_On_Error = "no";
    $db->query("SELECT username from ".DB_TABLEUSERS." where username='$username'");
    if($db -> num_rows() !== 0 )
      return true;
  }
  return false;
}



//create USER ?
if($_POST['create_user']){
  if($_POST['username'] === '' )
    $message='<font color="red">Error: Username is empty</font>';
  elseif($_POST["password"] !== $_POST["password2"])
    $message='<font color="red">Error: Passwords given are not identical</font>';
  elseif($_POST["password"] === '')
    $message='<font color="red">Error:Password can\'t be empty</font>';
  elseif(usernameexists($_POST['username']))
    $message='<font color="red">Error : Username allready exists</font>';
  else{
    //Realy create:
    $db=DbConnect();
    $db -> Halt_On_Error = "no";
    $userinfos=serialize(array(
    'search'=>$_POST['search'],
    'discols'=>$_POST['discols'],
    ));
    $query ="INSERT INTO ".DB_TABLEUSERS." SET ";
    $query.=" username='".$_POST['username']."' ,";
    $query.=" password=SHA1('".$_POST["password"]."+".SALT."') ,";
    $query.=" userinfos='$userinfos' ,";
    $query.=" admin='".$_POST['admin']."' ,";
    $query.=" updated=NOW(), created=NOW() ";
    $db -> query($query);
    //echo "AFF: ".$db->affected_rows();
    ?>
    <!-- Report Creation -->
    <center>
    <table width="60%" border="0"><tr>
    <td colspan="2" align="center">
    <h1>User <?php echo $_POST['username']?> has been created</h1>
    </td></tr>
    <tr>
    <td align="center">
    </td>
    <td align="center">
    <a href="?s=14" title="Back to Users list"><img src="images/back.png" border="0"><br>Continue</a>
    </td>
    </tr></table></center>
    <?php return;
  }
}

?>


<center>
<b>Creating a new user</b><br><br>
<FORM METHOD=POST ACTION="?s=<?php echo $s?>">
<table class="bar-status" width="450" border="0" cellspacing="1" cellpadding="2" align="center">
<tbody>
<?php
//Generate array from GLOBALS
$discols_array['default']='';
$search_array['default']='';

foreach($GLOBALS as $key=>$value){
  $res_cols=extract_var('_FG_TABLE_COL',$key);
  $res_search=extract_var('_VCHAR_SEARCH',$key);
  if($res_cols)
    $discols_array[$res_cols]=$res_cols;
  if($res_search)
    $search_array[$res_search]=$res_search;
}


$colors = array ( 1 => array ('555577','cddeff'), 0 => array('000033','acbdee'));
$INPUTS=array(
  "username"  => array('desc'=>"User Name :",'type'=>"input",'size'=>'18','value'=>$_POST['username']),
  "password"  => array('desc'=>"New Password :",'type'=>"password",'size'=>'18','value'=>$_POST['password']),
  "password2" => array('desc'=>"Confirm Password :",'type'=>"password",'size'=>'18','value'=>$_POST['password2']),
  "search"  => array('desc'=>"Search View :",'type'=>"select", 'value'=>$_POST['search'],'values'=>$search_array),
  "discols"  => array('desc'=>"Log View :",'type'=>"select", 'value'=>$_POST['discols'],'values'=>$discols_array),
  "admin" => array('desc'=>"Administrator :",'type'=>"checkbox",'value'=>$_POST['admin']==1?'checked':''),
);
foreach($INPUTS as $varname => $description){
$cpt++;


?>
		<tr>
				<td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][0]?>">			
					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?php echo $description['desc']?></b></font>
				</td>				
				<td class="bar-search" align="left" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr>
          <?php switch ($description['type']) {
            case "select":?><td>&nbsp;&nbsp;
          <?php echo gen_select($description['values'],$varname,$description['value']);?></td>
            <?php break;
            case "checkbox":?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?php echo $description['type']?>" NAME="<?php echo $varname?>" value="1" <?php echo $description['value']?>"></td>
            <?php break;
            default:?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?php echo $description['type']?>" NAME="<?php echo $varname?>" value="<?php echo $description['value']?>" size="<?php echo $description['size']?>"></td>
            <?php break;?>
          <?php }?>
  				</tr>
        </table></td>
			</tr>			
	<?php
} 
$cpt++;
?>
     <td class="bar-search" align="left" bgcolor="#<?php echo $colors[$cpt%2][0]?>"> </td>
				<td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
					<input type="submit" align="top" border="0" name="create_user" value="Create New User" />
	  			</td>
    		</tr>
		</tbody></table>
	</FORM>
<br>
<?php
if($message)
  echo "$message";
else
  echo "<br>";
?>
</center>
